@@ -18,7 +18,7 @@
 # standard libraries
 
 # external packages
-from PyQt5.QtCore import pyqtSignal, QObject
+from PyQt5.QtCore import pyqtSignal, QObject, QMutex
 from PyQt5.QtGui import QPixmap
 from qimage2ndarray import array2qimage
 import numpy as np
@@ -36,6 +36,8 @@ class KeypadSignals(QObject):
     textRow = pyqtSignal(object, object)
     imgChunk = pyqtSignal(object, object, object)
     keyPressed = pyqtSignal(object)
+    mousePressed = pyqtSignal(object)
+    mouseReleased = pyqtSignal(object)
     cursorPos = pyqtSignal(object, object)
 
 
@@ -45,8 +47,7 @@ class KeypadWindow(toolsQtWidget.MWidget):
 
     """
 
-    __all__ = ['KeypadWindow',
-               ]
+    __all__ = ['KeypadWindow']
 
     def __init__(self, app):
         super().__init__()
@@ -57,6 +58,7 @@ class KeypadWindow(toolsQtWidget.MWidget):
         self.signals = KeypadSignals()
         self.keypad = KeyPad(self.signals)
         self.buttons = None
+        self.websocketMutex = QMutex()
         self.graphics = np.zeros([64, 128, 3], dtype=np.uint8)
         self.rows = [
             self.ui.row0,
@@ -179,21 +181,31 @@ class KeypadWindow(toolsQtWidget.MWidget):
         }
         for button in self.buttons:
             if connect:
-                button.clicked.connect(self.buttonPress)
+                button.pressed.connect(self.buttonPressed)
+                button.released.connect(self.buttonReleased)
             else:
-                button.clicked.disconnect(self.buttonPress)
+                button.pressed.disconnect(self.buttonPressed)
+                button.released.disconnect(self.buttonReleased)
+        return True
+
+    def websocketClear(self):
+        """
+        :return:
+        """
+        self.websocketMutex.unlock()
         return True
 
     def startKeypad(self):
         """
         :return:
         """
-        if self.keypad.ws is not None:
+        if not self.websocketMutex.tryLock():
             return False
 
         self.clearDisplay()
         self.writeTextRow(2, 'Connecting ...')
         worker = Worker(self.keypad.workerWebsocket, self.app.mount.host)
+        worker.signals.finished.connect(self.websocketClear)
         self.threadPool.start(worker)
         return True
 
@@ -205,7 +217,7 @@ class KeypadWindow(toolsQtWidget.MWidget):
         self.startKeypad()
         return True
 
-    def buttonPress(self):
+    def buttonPressed(self):
         """
         :return:
         """
@@ -214,7 +226,19 @@ class KeypadWindow(toolsQtWidget.MWidget):
             return False
 
         keyData = self.keypad.buttonCodes[self.buttons[button]]
-        self.signals.keyPressed.emit(keyData)
+        self.signals.mousePressed.emit(keyData)
+        return True
+
+    def buttonReleased(self):
+        """
+        :return:
+        """
+        button = self.sender()
+        if button not in self.buttons:
+            return False
+
+        keyData = self.keypad.buttonCodes[self.buttons[button]]
+        self.signals.mouseReleased.emit(keyData)
         return True
 
     def writeTextRow(self, row, text):
