@@ -21,31 +21,20 @@
 
 # local imports
 from base.alpacaClass import AlpacaClass
-from base.alpacaBase import ObservingConditions
 
 
 class WeatherUPBAlpaca(AlpacaClass):
     """
     """
 
-    __all__ = ['WeatherUPBAlpaca',
-               ]
-    CYCLE_POLL_DATA = 1000
+    __all__ = ['WeatherUPBAlpaca']
 
     def __init__(self, app=None, signals=None, data=None):
         super().__init__(app=app, data=data, threadPool=app.threadPool)
 
-        self.client = ObservingConditions()
         self.signals = signals
         self.data = data
 
-    def getInitialConfig(self):
-        """
-        :return: true for test purpose
-        """
-        super().getInitialConfig()
-        return True
-
     def workerPollData(self):
         """
         :return: true for test purpose
@@ -53,7 +42,10 @@ class WeatherUPBAlpaca(AlpacaClass):
         if not self.deviceConnected:
             return False
 
-        self.data['WEATHER_PARAMETERS.WEATHER_TEMPERATURE'] = self.client.temperature()
-        self.data['WEATHER_PARAMETERS.WEATHER_DEWPOINT'] = self.client.dewpoint()
-        self.data['WEATHER_PARAMETERS.WEATHER_HUMIDITY'] = self.client.humidity()
+        self.getAndStoreAlpacaProperty('temperature',
+                                       'WEATHER_PARAMETERS.WEATHER_TEMPERATURE')
+        self.getAndStoreAlpacaProperty('dewpoint',
+                                       'WEATHER_PARAMETERS.WEATHER_DEWPOINT')
+        self.getAndStoreAlpacaProperty('humidity',
+                                       'WEATHER_PARAMETERS.WEATHER_HUMIDITY')
         return True
