@@ -24,6 +24,9 @@ from queue import Queue
 import platform
 
 # external packages
+if platform.system() == 'Windows' and platform.python_version() >= '3.8.2':
+    from logic.automation.automateWindows import AutomateWindows
+
 from PyQt5.QtCore import QObject, pyqtSignal, QThreadPool, QTimer
 from skyfield.api import wgs84
 from importlib_metadata import version
@@ -63,7 +66,6 @@ class MountWizzard4(QObject):
 
     __all__ = ['MountWizzard4']
     __version__ = version('mountwizzard4')
-
     log = logging.getLogger(__name__)
 
     message = pyqtSignal(str, int)
@@ -79,6 +81,8 @@ class MountWizzard4(QObject):
     showImage = pyqtSignal(str)
     showAnalyse = pyqtSignal(str)
     remoteCommand = pyqtSignal(str)
+    colorChange = pyqtSignal()
+    hostChanged = pyqtSignal()
 
     update0_1s = pyqtSignal()
     update1s = pyqtSignal()
@@ -96,11 +100,7 @@ class MountWizzard4(QObject):
     start10s = pyqtSignal()
     start30s = pyqtSignal()
 
-    def __init__(self,
-                 mwGlob=None,
-                 application=None
-                 ):
-
+    def __init__(self, mwGlob=None, application=None):
         super().__init__()
 
         self.application = application
@@ -111,7 +111,6 @@ class MountWizzard4(QObject):
         self.mainW = None
         self.threadPool = QThreadPool()
         self.threadPool.setMaxThreadCount(30)
-        self.threadPool.setExpiryTimeout(3)
         self.message.connect(self.writeMessageQueue)
         self.config = {}
         self.loadConfig()
@@ -135,8 +134,9 @@ class MountWizzard4(QObject):
         }
         profile = self.config.get('profileName', '-')
         self.messageQueue.put(('MountWizzard4 started', 1))
-        self.messageQueue.put((f'Workdir is: [{self.mwGlob["workDir"]}]', 1))
-        self.messageQueue.put((f'Profile              [{profile}] loaded', 1))
+        t = f'Workdir              [{self.mwGlob["workDir"]}]'
+        self.messageQueue.put((t, 1))
+        self.messageQueue.put((f'Loaded profile       [{profile}]', 1))
 
         # initialize commands to mount
         pathToData = self.mwGlob['dataDir']
@@ -146,7 +146,6 @@ class MountWizzard4(QObject):
                                    pathToData=pathToData,
                                    verbose=False,
                                    )
-
         # setting location to last know config
         topo = self.initConfig()
         self.mount.obsSite.location = topo
@@ -196,14 +195,10 @@ class MountWizzard4(QObject):
 
         :return:
         """
-        if platform.system() != 'Windows':
-            return None
-        if platform.python_version() < '3.8.2':
+        if platform.system() != 'Windows' or platform.python_version() < '3.8.2':
             return None
 
-        from logic.automation.automateWindows import AutomateWindows
         automation = AutomateWindows(self)
-
         return automation
 
     def initConfig(self):
@@ -292,7 +287,6 @@ class MountWizzard4(QObject):
         """
         self.aboutToQuit()
         self.deviceStat['mount'] = False
-        self.threadPool.waitForDone(5000)
         self.message.emit('MountWizzard4 manual stopped', 1)
         self.application.quit()
         return True
